import React, { useState, useEffect } from "react";
import SystemVersionComponent from "./SystemVersionComponent";
import { routes, get, endpoints } from "../../../utils/api";
import useSWR from "swr";
import { fetcher } from "utils/swr";
import { blip } from "utils";

const SystemVersionContainer: React.FC = () => {
  const { data: namespaces } = useSWR<any[], Error>(endpoints.system.version, fetcher, {
    revalidateOnFocus: false,
    onError: err => blip.error(err.message)
  });

  const [state, setState] = useState({ data: {}, loaded: false });

  useEffect(() => {
    if (state.loaded) return;
    get(routes.systemVersion, {
      onCompleted: (data: any) => setState({ data, loaded: true })
    });
  }, [state.loaded]);

  return <>{state.loaded && <SystemVersionComponent data={state.data} />}</>;
};

export default SystemVersionContainer;
